import bb.cascades 1.2
import "Squircle"

Page {
    id: thisPage
    
    property alias dataModel: listView.dataModel
    property alias titleBarTitle: titleBar.title

    titleBar: TitleBar { id: titleBar }

    onCreationCompleted: {
        if (navigationPane.indexOf(navigationPane.top) >= 0)
            addAction(backToRootAction)
    }
    
    attachedObjects: [
        BackToRootOnBarOrSignature {
            id: backToRootAction
        }
    ]
    
    Container {
        layout: DockLayout {}
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        background: Color.Black
        ImageView {
            imageSource: "asset:///images/brushed.jpg"
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            scalingMethod: ScalingMethod.AspectFill
        }
        ListView {
            id: listView
            
            property bool isGridListLayout: navigationPane.isGridListLayout
//            property bool isUnreadableHidden: navigationPane.isUnreadableHidden
            property bool isWritableShown: navigationPane.isWritableShown
            
            scrollRole: navigationPane.tutorialOpened ? ScrollRole.None : ScrollRole.Main
            layout: navigationPane.isGridListLayout ? gridListLayout : stackListLayout
            attachedObjects: [
                GridListLayout {
                    id: gridListLayout
                    headerMode: ListHeaderMode.Standard 
                    columnCount: navigationPane.columnCount
                },
                StackListLayout {
                    id: stackListLayout
                }
            ]
            onTriggered: {
                if (dataModel.data(indexPath).isDir) {
                    if (dataModel.data(indexPath).isReadable) {
                        var page = listViewPage.createObject()
                        page.dataModel = _fileSystem.getFileInfoList(dataModel.data(indexPath).completePath)
                        page.titleBarTitle = _fileSystem.currentPath
                        navigationPane.push(page)
                    }
                    else {
                        systemToast.body = "This folder is not readable"
                        systemToast.show()
                    }
                }
                else {
                    var page = fileContent.createObject()
                    page.completePath = dataModel.data(indexPath).completePath
                    page.fileName = dataModel.data(indexPath).fileName
                    page.isImage = _fileSystem.checkIfIsImage(dataModel.data(indexPath).completePath)
                    if (!page.isImage)
                        page.fileContent = _fileSystem.loadFile(dataModel.data(indexPath).completePath)
                    navigationPane.push(page)
                }
            }
            listItemComponents: [
                ListItemComponent {
                    type: "header"
                    Container { /* empty, don't want to show header */ }
                },
                ListItemComponent {
                    type: "item"
                    Container {
                        id: itemContainer
                        layout: DockLayout {}
                        horizontalAlignment: HorizontalAlignment.Fill
                        verticalAlignment: VerticalAlignment.Fill
                        opacity: (ListItemData.isReadable ? 1 : 0.5)
//                        visible: !(!ListItemData.isReadable && itemContainer.ListItem.view.isUnreadableHidden)
                        StandardListItem {
                            visible: !itemContainer.ListItem.view.isGridListLayout
                            imageSource: ListItemData.isDir ? (ListItemData.isReadable ? "asset:///images/folderReadable.png" : "asset:///images/folderNotReadable.png") : (ListItemData.isReadable ? "asset:///images/fileReadable.png" : "asset:///images/fileNotReadable.png")
                            title: ListItemData.fileName
                        }
                        Container {
                            layout: DockLayout {}
                            horizontalAlignment: HorizontalAlignment.Fill
                            verticalAlignment: VerticalAlignment.Fill
                            visible: itemContainer.ListItem.view.isGridListLayout
                            ImageView {
                                id: imageView
                                imageSource: ListItemData.isDir ? (ListItemData.isReadable ? "asset:///images/folderReadable.png" : "asset:///images/folderNotReadable.png") : (ListItemData.isReadable ? "asset:///images/fileReadable.png" : "asset:///images/fileNotReadable.png")
                                scalingMethod: ScalingMethod.AspectFit
                                horizontalAlignment: HorizontalAlignment.Fill
                                verticalAlignment: VerticalAlignment.Fill
                            }
                            Container {
                                horizontalAlignment: HorizontalAlignment.Center
                                verticalAlignment: VerticalAlignment.Center
                                Label {
                                    id: label
                                    text: ((ListItemData.isWritable && itemContainer.ListItem.view.isWritableShown) ? "*" : "") + ListItemData.fileName
//                                    text: ListItemData.fileName
                                    textStyle.color: Color.White
                                    multiline: true
                                }
                            }
                        }
                    }
                }
            ]
        }
    }
}
