/*
 * Copyright (c) 2011-2014 BlackBerry Limited.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import bb.cascades 1.2
import bb.system 1.2
import "Tutorial"

NavigationPane {
    id: navigationPane

    property int columnCount: _settings.value("ColumnCountDropDown", 3)
    property bool isGridListLayout: _settings.value("isGridListLayoutDropDown", true)
    property bool tutorialOpened: false
//    property bool isUnreadableHidden: _settings.value("isUnreadableHiddenDropDown", false)
    property bool isWritableShown: _settings.value("isWritableShown", false)
    
    onIsWritableShownChanged: { _settings.setValue("isWritableShown", isWritableShown) }
    
    attachedObjects: [
        AppCover { id: appCover },
        SystemToast { id: systemToast },
        TutorialSheet { id: tutorialSheet },
        ComponentDefinition { id: menu },
        ComponentDefinition {
            id: fileContent
            source: "FileContent.qml"
        },
        ComponentDefinition {
            id: listViewPage
            source: "ListViewPage.qml"
        }
    ]

    Menu.definition: MenuDefinition {
        settingsAction: [
            SettingsActionItem {
                ActionBar.placement: ActionBarPlacement.OnBar
                onTriggered: {
                    menu.source = "SettingsPage.qml";
                    var page = menu.createObject();
                    
                    // Push the new Page.
                    Application.menuEnabled = false;
                    navigationPane.push(page);
                }
            }
        ]
        actions: [
            ActionItem {
                title: qsTr("About")
                imageSource: "asset:///images/ic_info.png"
                ActionBar.placement: ActionBarPlacement.OnBar
                onTriggered: {
                    menu.source = "AboutPage.qml";
                    var page = menu.createObject();
                    
                    // Push the new Page.
                    Application.menuEnabled = false;
                    navigationPane.push(page);
                }
            }
        ]
    } // end of MenuDefinition

    onCreationCompleted: {
        Application.setCover(appCover)
        
        if (_settings.value("showFirstTimeTutorial", true)) 
            tutorialSheet.open()

        var page = listViewPage.createObject()
        page.dataModel = _fileSystem.getFileInfoList("//")
        page.titleBarTitle = _fileSystem.currentPath
        navigationPane.push(page)
    }
    
    onPopTransitionEnded: {
        page.destroy();
        
        Application.menuEnabled = true
    }
}
